#!/bin/bash
# Start azsecpack container

# Get script dir
SCRIPT_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

# Set variables.
# APDOCKER_DOMAIN is set in from the systemd .service file
LINUX_GENEVA_REGISTRY="linuxgeneva-microsoft.azurecr.io${APDOCKER_DOMAIN}"
MDSD_IMAGE="${LINUX_GENEVA_REGISTRY}/genevamdsd:master_777"
MDSD_SERVICE_NAME="apgenevamdsdsyslog"
DATAROOT="/ap/data"
DATA_GENEVA="${DATAROOT}/aplinux_geneva"
MDSD_DATA_DIR="${DATA_GENEVA}/mdsd_syslog"
MDSD_RUN_DIR="${DATA_GENEVA}/runmdsd_syslog"
AP_TOOLS_DIR="/ap/app/aptools"

# Source environment variables for the machine to pass to MDSD
source ${SCRIPT_DIR}/mdsd.env
source /etc/profile.d/ap.sh

# Pull a fresh ACR connection config every start
# We'll only capture stdout to ACR_CONNECTION_STRING, which will be empty on failure
ACR_CONNECTION_STRING=$(${AP_TOOLS_DIR}/apsecret_refresh_acr.py)
if [ $? -ne 0 ]
then
    echo "WARNING: Could not grab the most recent connection configuration for ACR."
fi

if [ -z "${ACR_CONNECTION_STRING}" ]
then
    echo "ERROR: Could not read the cached connection configuration for ACR."
    exit -1
fi

# Turn the connection string into an array
ACR_CONFIG=( ${ACR_CONNECTION_STRING} )
ACR_CLIENT_ID="${ACR_CONFIG[0]}"
ACR_CLIENT_KEY="${ACR_CONFIG[1]}"

if [ -z "${ACR_CLIENT_ID}" ] || [ -z "${ACR_CLIENT_KEY}" ]
then
    echo "ERROR: Invalid connection configuration cached for ACR."
    exit -1
fi

# Don't bother logging in and pulling the image if its already been done
if [[ "$(docker images -q ${MDSD_IMAGE} 2> /dev/null)" == "" ]]
then
    # Login to aplinux registry and pull the image
    docker login -u ${ACR_CLIENT_ID} -p ${ACR_CLIENT_KEY} ${LINUX_GENEVA_REGISTRY}
    docker pull ${MDSD_IMAGE}
    docker logout "${LINUX_GENEVA_REGISTRY}"
fi

# Pull a fresh set of MDSD secrets every start
${AP_TOOLS_DIR}/apsecret_refresh_geneva_warm.py -d ${MDSD_DATA_DIR} -n "syslog"

# Just in case the container was stopped but not removed (happens during a HardReboot),
# remove the old container. The old container holds a lock on the name that we'll need
# to get things up and running again. Ignoring errors because this is a "best effort"
# cleanup and the error message for failing to cleanup is very specific.
! docker stop ${MDSD_SERVICE_NAME} > /dev/null 2>&1
! docker rm -f ${MDSD_SERVICE_NAME} > /dev/null 2>&1

# Get the container up and automatically clean it up on exit
docker run --rm --name=${MDSD_SERVICE_NAME} -v ${MDSD_DATA_DIR}:/tmp/geneva_mdsd -v ${MDSD_RUN_DIR}:/var/run/mdsd --net=host --uts=host -e AP_CLUSTER -e AP_ENVIRONMENT -e AP_MACHINE_FUNCTION ${MDSD_IMAGE} /usr/sbin/mdsd -p 0
